about summary refs log tree commit diff
path: root/app/services
diff options
context:
space:
mode:
authorMatt Jankowski <mjankowski@thoughtbot.com>2017-05-08 18:45:02 -0400
committerEugen Rochko <eugen@zeonfederated.com>2017-05-09 00:45:02 +0200
commit5bea42412e41b1121af04dbe6ef5c9bed22219b8 (patch)
treef121a12cd27f567f8d7d7f7066ff302240d24dd2 /app/services
parent04166c4a35c97f5540252617c7858bf20d315a7e (diff)
Services specs for subscribe and unsubscribe (#2928)
* Add specs for unsubscribe service

* Fix non existent methods in unsubscribe service

* Clean up status handling in subscribe service
Diffstat (limited to 'app/services')
-rw-r--r--app/services/subscribe_service.rb16
-rw-r--r--app/services/unsubscribe_service.rb4
2 files changed, 10 insertions, 10 deletions
diff --git a/app/services/unsubscribe_service.rb b/app/services/unsubscribe_service.rb
index 1a951d1b4..6db8dbdc4 100644
--- a/app/services/unsubscribe_service.rb
+++ b/app/services/unsubscribe_service.rb
@@ -5,8 +5,8 @@ class UnsubscribeService < BaseService
     subscription = account.subscription(api_subscription_url(account.id))
     response = subscription.unsubscribe
 
-    unless response.successful?
-      Rails.logger.debug "PuSH unsubscribe for #{account.acct} failed: #{response.message}"
+    unless response.status.success?
+      Rails.logger.debug "PuSH unsubscribe for #{account.acct} failed: #{response.status}"
     end
 
     account.secret = ''
diff --git a/app/services/subscribe_service.rb b/app/services/subscribe_service.rb
index 138718f14..1e7984a7f 100644
--- a/app/services/subscribe_service.rb
+++ b/app/services/subscribe_service.rb
@@ -8,28 +8,28 @@ class SubscribeService < BaseService
     response     = subscription.subscribe
 
     if response_failed_permanently?(response)
-      # An error in the 4xx range (except for 429, which is rate limiting)
-      # means we're not allowed to subscribe. Fail and move on
+      # We're not allowed to subscribe. Fail and move on.
       account.secret = ''
       account.save!
     elsif response_successful?(response)
-      # Anything in the 2xx range means the subscription will be confirmed
-      # asynchronously, we've done what we needed to do
+      # The subscription will be confirmed asynchronously.
       account.save!
     else
       # What's left is the 5xx range and 429, which means we need to retry
       # at a later time. Fail loudly!
       raise "Subscription attempt failed for #{account.acct} (#{account.hub_url}): HTTP #{response.code}"
     end
   end
 
   private
 
+  # Any response in the 3xx or 4xx range, except for 429 (rate limit)
   def response_failed_permanently?(response)
-    response.code > 299 && response.code < 500 && response.code != 429
+    (response.status.redirect? || response.status.client_error?) && !response.status.too_many_requests?
   end
 
+  # Any response in the 2xx range
   def response_successful?(response)
-    response.code > 199 && response.code < 300
+    response.status.success?
   end
 end
@@ -8,28 +8,28 @@ class SubscribeService < BaseService
       account.save!
     else
-      # What's left is the 5xx range and 429, which means we need to retry
-      # at a later time. Fail loudly!
+      # The response was either a 429 rate limit, or a 5xx error.
+      # We need to retry at a later time. Fail loudly!
       raise "Subscription attempt failed for #{account.acct} (#{account.hub_url}): HTTP #{response.code}"
     end